/**<pre>
 * Title: iSIM
 * Copyright: Copyright (c) 2002
 * Company:   University of Oregon Computer Science Dept.
 *
 * @author Jason Prideaux
 * @version 1.0
 * </pre>
 */

package map;

import util.*;

/* ====================================================================== */
/** This class
 *
 */
public class Opening implements java.io.Serializable{


	/** The gps Position of 1st endpoint. */
  	private Position position1;

	/** The gps Position of 2nd endpoint. */
  	private Position position2;

  	/** The top location of the opening (no more than height). */
  	private int top;

  	/** The bottom location 0 for floor. */
  	private int bottom;

	/** The wireless signal degredation caused by this furnishing. */
  	private double rf_degredation;

	/** The sound level degredation caused by this furnishing. */
  	private double sound_degredation;

	/** The transparency of this opening. */
  	private double transparency;

	/** Whether the opening is open or closed. */
	private boolean open;

	/** Filename of image texture. */
	private String texture_filename;


    /* ===================================================================== */
    /** This constructor initializes the
     *
     *  @param  p1   The first endpoint.
     *  @param  p2   The second endpoint.
     *  @param  rf   The rf degredation.
     *  @param  sd   The sound degredation.
     *  @param  t   The top.
     *  @param  b   The bottom.
     *  @param  tr    The transparency.
     *  @param  o    Open or not.
     *  @param  f    The texture.
     *
     */
  	public Opening(Position p1, Position p2, double rf, double sd, int t, int b, double tr, boolean o, String f){

		position1 = p1;
		position2 = p2;
		rf_degredation = rf;
		sound_degredation = sd;
		top = t;
		bottom = b;
		transparency = tr;
		open = o;
		texture_filename = f;

	} //Constructor


    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public boolean isOpen(){

		return open;

	} //method:



    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public void setOpen(boolean o){

		open = o;

	} //method:

    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public Position getPosition1(){

		return position1;

	} //method:

    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public Position getPosition2(){

		return position2;

	} //method:



    /* ===================================================================== */
    /** This method returns the
     *
     *  @param
     *
     */
	public void setPosition1(Position p){

		position1 = p;

	} //method:

    /* ===================================================================== */
    /** This method returns the
     *
     *  @param
     *
     */
	public void setPosition2(Position p){

		position2 = p;

	} //method:

    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public double getRFDegredation(){

		return rf_degredation;

	} //method:

    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public double getSoundDegredation(){

		return sound_degredation;

	} //method:


    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public int getTop(){

		return top;

	} //method:

    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public int getBottom(){

		return bottom;

	} //method:


    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public void setRFDegredation(double d){

		rf_degredation = d;

	} //method:

    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public void setSoundDegredation(double d){

		sound_degredation = d;

	} //method:

    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public double getTransparency(){

		return transparency;

	} //method:

    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public void setTransparency(double d){

		transparency = d;

	} //method:

    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public String getTexture(){

		return texture_filename;

	} //method:

    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public void setTop(int d){

		top = d;

	} //method:

    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public void setBottom(int d){

		bottom = d;

	} //method:


    /* ===================================================================== */
    /** This method returns the
     *
     *  @return
     *
     */
	public void setTexture(String d){

		texture_filename = d;

	} //method:


} //class: Opening

