/**<pre>
 * Title: iSIM
 * Copyright: Copyright (c) 2002
 * Company:   University of Oregon Computer Science Dept.
 *
 * @author Jason Prideaux
 * @version 1.0
 * </pre>
 */

package recorder;

import gui.*;
import util.*;
import agent.*;
import agent.autonomous.*;
import controller.*;
import map.*;

import java.awt.*;
import java.util.*;



/* ====================================================================== */
/** This class is used by the simulation controller to
 *
 */
public class RecorderThread extends Thread{


	/** The iSIM controller. */
	private Controller controller;

	/** True if this thread is to record agent movements. */
	private boolean recording = false;

	/** True if recording all agents movements. */
	private boolean all = false;

	/** If recording just one agent movement this is it. */
	private User user;

	/** Hold a list of agent movements. */
	private Vector record = new Vector();



    /* ===================================================================== */
    /** This constructor initializes the thread and starts it running.
     *
     *  @param  controller   The iSIM controller.
     *
     */
	public RecorderThread(Controller controller){

		this.controller = controller;
		this.start();

	} //Constructor




    /* ===================================================================== */
    /** This method is a continuous loop for thread.  Every 5 seconds (may
     *  change)  we send message to all the agents in the simulation.  The time
     *  time interval and the messages to send can be changed.
     *
     */
	public void run(){

		while(true){

			try{ Thread.sleep(50); }catch(Exception e){}

			if( recording ){
				Vector users = controller.getUsers();
				User a = null;

				for( int i=0; i <users.size(); i++ ){
					a = (User)users.elementAt(i);

					//check the user's location and adjust vitals
					Point p = a.getLocation();
					double h = a.getPosition().getHeading();

					if( all ){
						record.add(new Record(a.getPort(), new Point(p.x, p.y), h));
					}else{
						if( user != null && user.getPort() == a.getPort() ){
							record.add(new Record(a.getPort(), new Point(p.x, p.y), h));
						}
					}

				}
			} //if

		} //while


    } //method: run



	public void stopRecording(){
		if(!all && user != null)
			user.setRecording(record);
		recording = false;
	}

	public void startRecording(){

		record = new Vector();
		all = true;
		recording = true;
	}

	public void startRecording(User u){

		user = u;
		record = new Vector();
		all = false;
		recording = true;
	}


	public Vector getLastRecording(){

		return record;

	}



} //class: RecorderThread