/**<pre>
 * Title: iSIM
 * Copyright: Copyright (c) 2002
 * Company:   University of Oregon Computer Science Dept.
 *
 * @author Jason Prideaux
 * @version 1.0
 * </pre>
 */

package state;

import gui.*;
import controller.*;

import java.awt.*;
import javax.swing.*;
import java.awt.event.*;



/* ====================================================================== */
/** This is the JDialog is just a Window to hold a panel, specifically the
 *  StatePanel.
 *
 */
public class StateWindow extends JDialog {

	/** The border layout to use for the Tray. */
    private BorderLayout bdrLayMain = new BorderLayout();

    /** The parent Frame that owns this JDialog. */
    private Frame parentFrame;

	/** StateMachine running this StateGUI. */
	private StateMachine statemachine;


    /* ===================================================================== */
    /** Constructor that creates this JDialog. The parent and StateMachine must
     *  not be null for this Dialog to function properly.
     *
     *  @param  parent   The owning frame of this dialog.
     *  @param  controller   The simulation controller.
     *
     */
    public StateWindow( Frame parent, StateMachine statemachine ) {

		super(parent);
        setTitle("State Machine");


        this.parentFrame = parent;
        this.statemachine = statemachine;

		// Setup the gui
        try {
          init();
        }
        catch(Exception e) {
          e.printStackTrace();
        }


		// Set the size and location
        this.pack();
        this.setSize(450, 230);

        Dimension screen = Toolkit.getDefaultToolkit().getScreenSize();
		int x = (screen.width - this.getWidth()) - 100;
        int y = 100;

        this.setLocation(x,y);

		// Show us.
        this.setVisible(true);

    } //Construtor




    // =======================================================================
    /** Initializes the GUI with components.
     *
     */
    private void init() throws Exception {

		// Adjust the border layout
        this.getContentPane().setLayout(bdrLayMain);
        bdrLayMain.setHgap(2);
        bdrLayMain.setVgap(2);


		// Make our size fixed.
        this.setResizable(false);


		// Add the tabs to this dialog.
        this.getContentPane().add(new StatePanel(statemachine), BorderLayout.CENTER);


    } //method: init


} //class: StateWindow
